@@ -60,6 +60,16 @@ class InMemoryCache:
             self.cache[cache_key].pop(vary, None)
 
 
+def _ldp_container_representation(id, container_permissions=None, value=None):
+    '''Utility function builds a LDP-format dictionary for passed container data'''
+    represented_object = {'@id': id}
+    if value is not None:
+        represented_object.update({'@type': 'ldp:Container', 'ldp:contains': value})
+    if container_permissions is not None:
+        represented_object.update({'permissions': container_permissions})
+    return represented_object
+
+
 class LDListMixin:
     '''A Mixin for serializing containers into JSONLD format'''
     child_attr = 'child'
@@ -113,7 +123,6 @@ class LDListMixin:
             container_permissions = Model.get_permissions(child_model, self.context, ['view', 'add'])
 
         else:
-            # this is a container. Parent model is the containing object, child the model contained
             try:
                 parent_model = Model.resolve_parent(self.context['request'].path)
             except:
@@ -126,19 +135,26 @@ class LDListMixin:
             if self.with_cache and self.to_representation_cache.has(cache_key, cache_vary):
                 return self.to_representation_cache.get(cache_key, cache_vary)
 
-            # filter the queryset automatically based on child model permissions classes (filter_backends)
+            container_permissions = Model.get_permissions(child_model, self.context, ['add'])
+            container_permissions.extend(Model.get_permissions(parent_model, self.context, ['view']))
+
+            # optimize: filter the queryset automatically based on child model permissions classes (filter_backends)
             if isinstance(value, QuerySet) and hasattr(child_model, 'get_queryset'):
                 value = child_model.get_queryset(self.context['request'], self.context['view'], queryset=value,
                                                  model=child_model)
 
-            container_permissions = Model.get_permissions(child_model, self.context, ['add'])
-            container_permissions.extend(
-                Model.get_permissions(parent_model, self.context, ['view']))
+        # if this field is listed as an "empty_container" it means that it should only be serialized with @id
+        if getattr(self, 'parent', None) is not None and getattr(self, 'field_name', None) is not None:
+            empty_containers = getattr(self.parent.Meta.model._meta, 'empty_containers', None)
 
-        self.to_representation_cache.set(self.id, cache_vary, {'@id': self.id,
-                                                   '@type': 'ldp:Container',
-                                                   'ldp:contains': super().to_representation(value),
-                                                   'permissions': container_permissions})
+            if empty_containers is not None and self.field_name in empty_containers:
+                self.to_representation_cache.set(self.id, cache_vary, _ldp_container_representation(self.id))
+                return self.to_representation_cache.get(self.id, cache_vary)
+
+        self.to_representation_cache.set(self.id, cache_vary,
+                                         _ldp_container_representation(self.id,
+                                                                       container_permissions=container_permissions,
+                                                                       value=super().to_representation(value)))
 
         return self.to_representation_cache.get(self.id, cache_vary)
 
@@ -384,15 +400,10 @@ class LDPSerializer(HyperlinkedModelSerializer):
                     if isinstance(instance, QuerySet):
                         data = list(instance)
 
-                        return {'@id': '{}{}{}/'.format(settings.SITE_URL, '{}{}/', self.source),
-                                '@type': 'ldp:Container',
-                                'ldp:contains': [serializer.to_representation(item) if item is not None else None for
-                                                 item
-                                                 in data],
-                                'permissions': Model.get_permissions(self.parent.Meta.model,
-                                                                     self.context,
-                                                                     ['view', 'add'])
-                                }
+                        id = '{}{}{}/'.format(settings.SITE_URL, '{}{}/', self.source)
+                        permissions = Model.get_permissions(self.parent.Meta.model, self.context, ['view', 'add'])
+                        data = [serializer.to_representation(item) if item is not None else None for item in data]
+                        return _ldp_container_representation(id, container_permissions=permissions, value=data)
                     else:
                         return serializer.to_representation(instance)
                 else:
